<?php

/**
  * Gestion de l'action `pdform_telecharger`
  *
  * Permet d'accéder, en téléchargement, au PDF
  *
  * @plugin Pdform pour Spip 4
  * @license GPL 2020-2022
  * @author Thrax
  *
  * @package SPIP\Pdform\Action
 **/

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

/**
  * Action qui propose en téléchargement le fichier PDF
  * dont le chemin est transmis au travers d'une action sécurisée. 
  *
  * @param void
  *     Utilise l'argument de l'action sécurisée.
  * @return PDF
  *
 **/

function action_pdform_telecharger() {

	// Securisation de l'argument nom de l'archive
	$securiser_action = charger_fonction('securiser_action', 'inc');
	$chemin_fichier = $securiser_action();

	// Si l'archive n'est pas accessible on renvoie une erreur
	if (!@is_readable($chemin_fichier)) {
		spip_log("Le fichier ${chemin_fichier} n'est pas accessible pour le téléchargement", 'pdform.' . _LOG_ERREUR);
	} else {
		// Autorisation
		if (!autoriser('telecharger','pdform')) {
			include_spip('inc/minipres');
			echo minipres();
			exit;
		}
	
		// Détermination de l'extension du fichier
		$extension = pathinfo($chemin_fichier, PATHINFO_EXTENSION);
	
		// Vider tous les tampons pour ne pas provoquer de Fatal memory exhausted
		$level = @ob_get_level();
		while ($level--) {
			@ob_end_clean();
		}
	
		// Telechargement du fichier d'archive
		header('Content-Description: File Transfer');
		header('Content-type: text/pdf');
		header('Content-Disposition: attachment; filename="' . basename($chemin_fichier) . '"');
		header('Content-Transfer-Encoding: binary');
		header('Pragma: public');
		header('Expires: 0');
		header('Cache-Control: must-revalidate, post-check=0, pre-check=0');
		header('Content-Length: ' . filesize($chemin_fichier));
		readfile($chemin_fichier);
		exit;
	}
}
